@@ -43,9 +43,13 @@ static CompilerTestSet testCases = {
     "test11.h", "test11.cpp",
     "test11a.h", "test11a.cpp",
     "test12.h", "test12.cpp",
+    "test13.h", "test13.cpp",
     "test_dpointer.cpp", "test_dpointer.h",
-    "test_signal.cpp", "test_signal.h",
     "test_qdebugcategory.cpp", "test_qdebugcategory.h",
+    "test_signal.cpp", "test_signal.h",
+    "test_translation_kde.cpp", "test_translation_kde.h",
+    "test_translation_kde_domain.cpp", "test_translation_kde_domain.h",
+    "test_translation_qt.cpp", "test_translation_qt.h",
     Q_NULLPTR
 };
 
@@ -63,9 +67,13 @@ static CompilerTestSet testCasesToRun = {
     "test10",
     "test11",
     "test12",
+    "test13",
     "test_dpointer",
-    "test_signal",
     "test_qdebugcategory",
+    "test_signal",
+    "test_translation_kde",
+    "test_translation_kde_domain",
+    "test_translation_qt",
     Q_NULLPTR
 };
 
@@ -79,7 +87,7 @@ static CompilerTestSet willFailCases = {
 
 void KConfigCompiler_Test::initTestCase()
 {
-    m_diffExe = QStandardPaths::findExecutable("diff");
+    m_diffExe = QStandardPaths::findExecutable( QStringLiteral("diff") );
     if (m_diffExe.isEmpty()) {
         qDebug() << "diff command not found, detailed info on comparison failure will not be available.";
     }
@@ -139,6 +147,7 @@ void KConfigCompiler_Test::testRunning()
 #endif
 
     QString program = QFINDTESTDATA(testName);
+    QVERIFY2(!program.isEmpty(), qPrintable(testName + QLatin1String(" must exist!")));
     QVERIFY2(QFile::exists(program), qPrintable(program + QLatin1String(" must exist!")));
     QProcess process;
     process.start(program, QIODevice::ReadOnly);
@@ -156,7 +165,7 @@ void KConfigCompiler_Test::appendFileDiff(const QString &oldFile, const QString
     }
 
     QStringList args;
-    args << "-u";
+    args << QStringLiteral("-u");
     args << QFileInfo(oldFile).absoluteFilePath();
     args << QFileInfo(newFile).absoluteFilePath();
 
